@@ -1,21 +1,21 @@
 """Value factoring with support for lazy dot paths."""
 
-from __future__ import absolute_import, division, print_function
-
 import six
-from tippo import TYPE_CHECKING
+from tippo import Any, Callable, Iterable, Mapping, TypeVar
 
 from .import_path import import_path
 
-if TYPE_CHECKING:
-    from tippo import Any, Callable, Iterable, Mapping
+__all__ = ["fabricate_value", "format_factory"]
 
-__all__ = ["fabricate_value"]
+
+T = TypeVar("T")
+
+MISSING = object()
 
 
 def fabricate_value(
     factory,  # type: str | Callable | None
-    value,  # type: Any
+    value=MISSING,  # type: Any
     args=None,  # type: Iterable | None
     kwargs=None,  # type: Mapping[str, Any] | None
     extra_paths=(),  # type: Iterable[str]
@@ -32,13 +32,34 @@ def fabricate_value(
     :param extra_paths: Extra module paths in fallback order.
     :param builtin_paths: Builtin module paths in fallback order.
     :return: Output value.
+    :raises ValueError: Factory is None and no value was provided.
     :raises TypeError: Invalid factory type.
     """
     if isinstance(factory, six.string_types):
         factory = import_path(factory, extra_paths=extra_paths, builtin_paths=builtin_paths)
     if factory is None:
+        if value is MISSING:
+            error = "no value and no factory provided"
+            raise ValueError(error)
         return value
     if not callable(factory):
         error = "{!r} object is not a valid callable factory".format(type(factory).__name__)
         raise TypeError(error)
-    return factory(value, *args or (), **kwargs or {})
+    if value is MISSING:
+        return factory(*args or (), **kwargs or {})
+    else:
+        return factory(value, *args or (), **kwargs or {})
+
+
+def format_factory(factory):
+    # type: (str | Callable[..., T] | None) -> str | Callable[..., T] | None
+    """
+    Format and check factory.
+
+    :param factory: Factory.
+    :return: Checked factory.
+    """
+    if factory is not None and not isinstance(factory, six.string_types) and not callable(factory):
+        error = "invalid factory type {!r}, expected None, a string, or a callable".format(type(factory).__name__)
+        raise TypeError(error)
+    return factory
