@@ -1,7 +1,5 @@
 """Mapping Proxy type (read-only) for older Python versions."""
 
-from __future__ import absolute_import, division, print_function
-
 __all__ = ["MappingProxyType"]
 
 
@@ -9,20 +7,27 @@ try:
     from types import MappingProxyType
 
 except ImportError:
-    from collections import Mapping  # type: ignore
+    from tippo import Mapping, Iterator, TypeVar  # type: ignore
 
-    class MappingProxyType(Mapping):  # type: ignore
+    KT = TypeVar("KT")
+    VT = TypeVar("VT")
+
+    class MappingProxyType(Mapping[KT, VT]):  # type: ignore
         __slots__ = ("__mapping",)
 
         def __init__(self, mapping):
+            # type: (Mapping[KT, VT]) -> None
             self.__mapping = mapping
 
         def __getitem__(self, item):
+            # type: (KT) -> VT
             return self.__mapping[item]
 
         def __len__(self):
+            # type: () -> int
             return len(self.__mapping)
 
         def __iter__(self):
+            # type: () -> Iterator[KT]
             for key in self.__mapping:
                 yield key
